@@ -26,9 +26,7 @@ logAlpha <- function(m)
     beta <- m$mle$beta
     delta <- m$mle$delta
 
-    covsCol <- which(names(data)!="ID" & names(data)!="x" & names(data)!="y" &
-                         names(data)!="step" & names(data)!="angle")
-    covs <- data[,covsCol]
+    covs <- model.matrix(m$conditions$formula, m$data)
 
     probs <- allProbs(data,nbStates,m$conditions$stepDist,m$conditions$angleDist,m$mle$stepPar,
                       m$mle$anglePar,m$conditions$zeroInflation,m$knownStates)
