@@ -3,6 +3,7 @@ context("nLogLike")
 
 test_that("Exceptions are thrown", {
     data <- example$data
+    covs <- model.matrix(example$m$conditions$formula, data = data)
     simPar <- example$simPar
     par0 <- example$par0
 
@@ -15,28 +16,38 @@ test_that("Exceptions are thrown", {
     par <- c(par0$stepPar0, par0$anglePar0)
     wpar <- n2w(par, bounds, par0$beta0, par0$delta0, simPar$nbStates, estAngleMean)
 
-    expect_error(nLogLike(wpar, simPar$nbStates, bounds, parSize, data, simPar$stepDist, simPar$angleDist,
-                         simPar$angleMean, simPar$zeroInflation), NA)
+    expect_error(nLogLike(wpar = wpar, nbStates = simPar$nbStates, bounds = bounds,
+                          parSize = parSize, data = data, covs = covs,
+                          stepDist = simPar$stepDist, angleDist = simPar$angleDist,
+                          angleMean = simPar$angleMean, zeroInflation = simPar$zeroInflation),
+                 NA)
 
     # if not enough parameters provided
-    expect_error(nLogLike(wpar[-1], simPar$nbStates, bounds, parSize, data, simPar$stepDist, simPar$angleDist,
-                         simPar$angleMean, simPar$zeroInflation))
+    expect_error(nLogLike(wpar = wpar[-1], nbStates = simPar$nbStates, bounds = bounds,
+                          parSize = parSize, data = data, covs = covs,
+                          stepDist = simPar$stepDist, angleDist = simPar$angleDist,
+                          angleMean = simPar$angleMean, zeroInflation = simPar$zeroInflation))
 
     # if stepDist not in list
-    expect_error(nLogLike(wpar, simPar$nbStates, bounds, parSize, data, "unif", simPar$angleDist,
-                         simPar$angleMean, simPar$zeroInflation))
+    expect_error(nLogLike(wpar = wpar, nbStates = simPar$nbStates, bounds = bounds,
+                          parSize = parSize, data = data, covs = covs,
+                          stepDist = "unif", angleDist = simPar$angleDist,
+                          angleMean = simPar$angleMean, zeroInflation = simPar$zeroInflation))
 
     # if angleDist not in list
     expect_error(nLogLike(wpar, simPar$nbStates, bounds, parSize, data, simPar$stepDist, "norm",
-                         simPar$angleMean, simPar$zeroInflation))
+                          simPar$angleMean, simPar$zeroInflation))
 
     data <- data[-2] # remove data$step
-    expect_error(nLogLike(wpar, simPar$nbStates, bounds, parSize, data, simPar$stepDist, simPar$angleDist,
-                         simPar$angleMean, simPar$zeroInflation))
+    expect_error(nLogLike(wpar = wpar, nbStates = simPar$nbStates, bounds = bounds,
+                          parSize = parSize, data = data, covs = covs,
+                          stepDist = simPar$stepDist, angleDist = simPar$angleDist,
+                          angleMean = simPar$angleMean, zeroInflation = simPar$zeroInflation))
 })
 
 test_that("angleMean = NULL, angleDist = NULL, and zeroInflation = TRUE work", {
     data <- example$data
+    covs <- model.matrix(example$m$conditions$formula, data = data)
     simPar <- example$simPar
     par0 <- example$par0
 
@@ -47,20 +58,22 @@ test_that("angleMean = NULL, angleDist = NULL, and zeroInflation = TRUE work", {
                       estAngleMean, TRUE)$parSize
 
     par0$stepPar0 <- c(par0$stepPar0, rep(0.2, simPar$nbStates)) # include zero mass parameters
-    par0$anglePar0 <- c(rep(0, simPar$nbStates), par0$anglePar0) # include angle mean parameters
     par <- c(par0$stepPar0, par0$anglePar0)
     wpar <- n2w(par, bounds, par0$beta0, par0$delta0, simPar$nbStates, estAngleMean)
 
-    expect_error(nLogLike(wpar, simPar$nbStates, bounds, parSize, data, simPar$stepDist, "none",
-                         NULL, TRUE), NA)
+    expect_error(nLogLike(wpar = wpar, nbStates = simPar$nbStates, bounds = bounds,
+                          parSize = parSize, data = data, covs = covs,
+                          stepDist = simPar$stepDist, angleDist = "none",
+                          angleMean = NULL, zeroInflation = TRUE),
+                 NA)
 })
 
 test_that("logAlpha, logBeta, and nLogLike are consistent", {
     m <- example$m
     data <- m$data
+    covs <- model.matrix(example$m$conditions$formula, data = data)
     simPar <- example$simPar
     nbAnimals <- simPar$nbAnimals
-    par <- c(t(c(m$mle$stepPar)), c(t(m$mle$anglePar))[3:4])
 
     estAngleMean <- m$conditions$estAngleMean
     bounds <- parDef(simPar$stepDist, simPar$angleDist, simPar$nbStates,
@@ -68,8 +81,10 @@ test_that("logAlpha, logBeta, and nLogLike are consistent", {
     parSize <- parDef(simPar$stepDist, simPar$angleDist, simPar$nbStates,
                       estAngleMean, simPar$zeroInflation)$parSize
 
-    nll <- nLogLike(m$mod$estimate, simPar$nbStates, bounds, parSize, data, simPar$stepDist, simPar$angleDist,
-                    simPar$angleMean, simPar$zeroInflation)
+    nll <- nLogLike(wpar = m$mod$estimate, nbStates = simPar$nbStates, bounds = bounds,
+                    parSize = parSize, data = data, covs = covs,
+                    stepDist = simPar$stepDist, angleDist = simPar$angleDist,
+                    angleMean = simPar$angleMean, zeroInflation = simPar$zeroInflation)
 
     la<-logAlpha(m)
     lb<-logBeta(m)
@@ -82,13 +97,18 @@ test_that("logAlpha, logBeta, and nLogLike are consistent", {
     expect_equal(nll, -ll)
 
     # random time step from each individual
+    set.seed(4574)
     for(i in 1:nbAnimals){
         data <- example$m$data
+        covs <- model.matrix(example$m$conditions$formula, data = data)
         aInd <- which(data$ID == i)
 
         data <- data[aInd, ]
-        nll <- nLogLike(m$mod$estimate, simPar$nbStates, bounds, parSize, data, simPar$stepDist, simPar$angleDist,
-                      simPar$angleMean, simPar$zeroInflation)
+        covs <- covs[aInd, ]
+        nll <- nLogLike(wpar = m$mod$estimate, nbStates = simPar$nbStates, bounds = bounds,
+                        parSize = parSize, data = data, covs = covs,
+                        stepDist = simPar$stepDist, angleDist = simPar$angleDist,
+                        angleMean = simPar$angleMean, zeroInflation = simPar$zeroInflation)
 
         samp <- sample(aInd, 1)
         c <- max(la[samp, ]+lb[samp, ]) # cancels below ; prevents numerical errors
